@@ -1,17 +1,17 @@
+
+import importlib
 import logging
 import os
+import pkgutil
+
 from importlib import import_module
-import datetime
-import aiohttp
-import yaml
-import subprocess
-import sys
+
 from cbpi.api import *
 from cbpi.utils.utils import load_config
+from importlib_metadata import metadata, version
 
 logger = logging.getLogger(__name__)
 
-
 class PluginController():
     modules = {}
     types = {}
@@ -21,7 +21,8 @@ class PluginController():
 
     def load_plugins(self):
 
-        this_directory = os.sep.join(os.path.abspath(__file__).split(os.sep)[:-1])
+        this_directory = os.sep.join(
+            os.path.abspath(__file__).split(os.sep)[:-1])
         for filename in os.listdir(os.path.join(this_directory, "../extension")):
             if os.path.isdir(
                     os.path.join(this_directory, "../extension/") + filename) is False or filename == "__pycache__":
@@ -30,7 +31,6 @@ class PluginController():
                 logger.info("Trying to load plugin %s" % filename)
                 data = load_config(os.path.join(
                     this_directory, "../extension/%s/config.yaml" % filename))
-
                 if (data.get("active") is True and data.get("version") == 4):
                     self.modules[filename] = import_module(
                         "cbpi.extension.%s" % (filename))
@@ -41,21 +41,27 @@ class PluginController():
                         "Plugin %s is not supporting version 4" % filename)
 
             except Exception as e:
-                print(e)
+
                 logger.error(e)
 
     def load_plugins_from_evn(self):
 
-        for p in self.cbpi.static_config.get("plugins", []):
+        discovered_plugins = {
+            name: importlib.import_module(name)
+            for finder, name, ispkg
+            in pkgutil.iter_modules()
+            if name.startswith('cbpi') and len(name) > 4
+        }
 
+        for key, value in discovered_plugins.items():
+            from importlib.metadata import version
             try:
-                logger.info("Try to load plugin:  %s " % p)
-                self.modules[p] = import_module(p)
-                self.modules[p].setup(self.cbpi)
-
-                logger.info("Plugin %s loaded successfully" % p)
+                logger.info("Try to load plugin:  {} == {} ".format(
+                    key, version(key)))
+                value.setup(self.cbpi)
+                logger.info("Plugin {} loaded successfully".format(key))
             except Exception as e:
-                logger.error("FAILED to load plugin %s " % p)
+                logger.error("FAILED to load plugin {} ".format(key))
                 logger.error(e)
 
     def register(self, name, clazz) -> None:
@@ -73,12 +79,20 @@ class PluginController():
         if issubclass(clazz, CBPiKettleLogic):
             self.cbpi.kettle.types[name] = self._parse_step_props(clazz, name)
 
+        if issubclass(clazz, CBPiFermenterLogic):
+            self.cbpi.fermenter.types[name] = self._parse_step_props(
+                clazz, name)
+
         if issubclass(clazz, CBPiSensor):
             self.cbpi.sensor.types[name] = self._parse_step_props(clazz, name)
 
         if issubclass(clazz, CBPiStep):
             self.cbpi.step.types[name] = self._parse_step_props(clazz, name)
 
+        if issubclass(clazz, CBPiFermentationStep):
+            self.cbpi.fermenter.steptypes[name] = self._parse_step_props(
+                clazz, name)
+
         if issubclass(clazz, CBPiExtension):
             self.c = clazz(self.cbpi)
 
@@ -98,6 +112,8 @@ class PluginController():
             return {"label": p.label, "type": "sensor", "configurable": p.configurable, "description": p.description}
         elif isinstance(p, Property.Kettle):
             return {"label": p.label, "type": "kettle", "configurable": p.configurable, "description": p.description}
+        elif isinstance(p, Property.Fermenter):
+            return {"label": p.label, "type": "fermenter", "configurable": p.configurable, "description": p.description}
 
     def _parse_step_props(self, cls, name):
 
@@ -114,7 +130,8 @@ class PluginController():
                 parameters = []
                 for p in method.__getattribute__("parameters"):
                     parameters.append(self._parse_property_object(p))
-                result["actions"].append({"method": method_name, "label": key, "parameters": parameters})
+                result["actions"].append(
+                    {"method": method_name, "label": key, "parameters": parameters})
 
         return result
 
@@ -158,6 +175,11 @@ class PluginController():
                 result["properties"].append(
                     {"name": m, "label": t.label, "type": "kettle", "configurable": t.configurable,
                      "description": t.description})
+            elif isinstance(tmpObj.__getattribute__(m), Property.Fermenter):
+                t = tmpObj.__getattribute__(m)
+                result["properties"].append(
+                    {"name": m, "label": t.label, "type": "fermenter", "configurable": t.configurable,
+                     "description": t.description})
 
         for method_name, method in cls.__dict__.items():
             if hasattr(method, "action"):
@@ -167,3 +189,29 @@ class PluginController():
                     {"method": method_name, "label": key, "parameters": parameters})
 
         return result
+
+    async def load_plugin_list(self, filter="cbpi"):
+        result = []
+        try:
+            discovered_plugins = {
+                name: importlib.import_module(name)
+                for finder, name, ispkg
+                in pkgutil.iter_modules()
+                if name.startswith(filter) and len(name) > 4
+            }
+            for key, module in discovered_plugins.items():
+                from importlib.metadata import version
+                try:
+                    from importlib.metadata import (distribution, metadata,
+                                                    version)
+                    meta = metadata(key)
+                    result.append({row: meta[row]
+                                  for row in list(metadata(key))})
+                except Exception as e:
+                    logger.error("FAILED to load plugin {} ".format(key))
+                    logger.error(e)
+
+        except Exception as e:
+            logger.error(e)
+            return []
+        return result
